@@ -5,16 +5,16 @@ import logging
 import random
 import uuid
 
+import gevent
+import requests
 from cached_property import cached_property
+from requests.exceptions import RequestException
 from selenium import webdriver
 from selenium.common.exceptions import TimeoutException
 from selenium.webdriver.common.by import By
 from selenium.webdriver.support import expected_conditions as EC
 from selenium.webdriver.support.ui import WebDriverWait
 from six.moves import urllib
-import gevent
-import requests
-from requests.exceptions import RequestException
 
 logger = logging.getLogger(__file__)
 
@@ -154,9 +154,9 @@ class BotBase(object):
         Answers the questions in the base questionnaire.
         """
         logger.info("Complete questionnaire.")
-        difficulty = self.driver.find_element_by_id("difficulty")
+        difficulty = self.driver.find_element("id", "difficulty")
         difficulty.value = "4"
-        engagement = self.driver.find_element_by_id("engagement")
+        engagement = self.driver.find_element("id", "engagement")
         engagement.value = "3"
 
     def sign_off(self):
