@@ -1,5 +1,5 @@
 """This is Dallinger, a platform for simulating evolution with people."""
 
-from .tools import app_name, auth_token, log_in, sanity_check, container_log_in
+from .tools import app_name, auth_token, container_log_in, log_in, sanity_check
 
 __all__ = ("app_name", "auth_token", "log_in", "container_log_in", "sanity_check")
